.. -*- mode: rst -*-

.. include:: changes/names.rst

====
Team
====

This work is made available by a community of people, which
originated from
the :inria:`INRIA MIND Project Team <mind>` and :sklearn:`scikit-learn <>`
but grew much further.

An up-to-date list of contributors can be seen in on
:nilearn-gh:`GitHub <graphs/contributors>`.

Additional credit goes to `Michael Hanke`_ and `Yaroslav Halchenko`_ for data and packaging.

.. CORE DEV SECTION STARTS HERE
   The Core developers section is added automatically
   and should not be edited manually.

.. _core_devs:

Core developers
...............

The nilearn core developers are:

* `Bertrand Thirion`_
* `Elizabeth DuPre`_
* `Hande Gözükan`_
* `Hao-Ting Wang`_
* `Himanshu Aggarwal`_
* `Jerome Dockes`_
* `Michelle Wang`_
* `Mohammad Torabi`_
* `Pierre-Louis Barbarant`_
* `Rémi Gau`_

.. CORE DEV SECTION ENDS HERE

.. OTHER CONTRIBUTION SECTION STARTS HERE
   The Other contributors section is added automatically
   and should not be edited manually.

Other contributors
..................

Some other past or present contributors are:

* `Ahmad Chamma`_: Inria, Saclay, France
* `Aina Frau-Pascual`_
* `Alex Rothberg`_: Free Agency, New York, USA
* `Alexandre Abadie`_: Inria, Paris
* `Alexandre Abraham`_: Bazemont, Île-de-France, France
* `Alexandre Gramfort`_: Meta, France
* `Alexandre Savio`_
* `Alexandre Cionca`_: Centre Hospitalier Universitaire Vaudoise, Lausanne, Switzerland
* `Alexandre Sayal`_: CIBIT, University of Coimbra, Portugal
* `Alexis Thual`_: Inria, Saclay, France
* `Alisha Kodibagkar`_: MIT McGovern Institute, Cambridge, Massachusetts, United States
* Amadeus Kanaan
* `Ana Luisa Pinho`_: Western University, London, Ontario, Canada
* `Anand Joshi`_: University of Southern California, Los Angeles, California, United States
* `Andrés Hoyos Idrobo`_: Rakuten, France
* `Anne-Sophie Kieslinger`_: Max Planck Institute for Human Cognitive and Brain Sciences, Leipzig, Germnay
* `Anupriya Kumari`_: Indian Institute of Technology, Roorkee, India
* `Ariel Rokem`_: University of Washington, Psychology, Seattle, Washington, 98107, USA
* `Arthur Mensch`_
* `Aswin Vijayan`_
* `Audrey Duran`_: TheraPanacea, France
* `Ben Cipollini`_: Facebook, Hayward, California, USA
* `Bertrand Thirion`_: Inria, Saclay, France
* `Binh Nguyen`_
* `Caglar Cakan`_: Technische Universität Berlin, Berlin, Germany
* `Chris Gorgolewski`_: Google LLC
* `Chris Markiewicz`_: Stanford University, Stanford, California, USA
* `Christian Horea`_: Dartmouth College, PBS, Hanover, New Hampshire, USA
* `Christian Gerloff`_
* `Christina Roßmanith`_: Dept. of Neurology, Medical Faculty Mannheim, University of Heidelberg, Germany
* `Colin Reininger`_: Denver, Colorado, USA
* `Connor Lane`_: Child Mind Institute, Baltimore, MD, USA
* `Czarina Sy`_
* `Céline Delettre`_
* `Dan Gale`_: Centre for Neuroscience Studie, Queen University, Kingston, Ontario, Canada
* `Daniel Gomez`_: Cambridge, Massachusetts, USA
* `Danilo Bzdok`_: McGill University & Mila Quebec AI Institute, Montréal, Canada
* `David G Ellis`_: University of Nebraska Medical Center, Nebraska, USA
* `Demian Wassermann`_: Inria, Saclay, France
* `Derek Pisner`_: St. Petersburg, FL
* `Dimitri Papadopoulos Orfanos`_: NeuroSpin, CEA, Université Paris-Saclay, Gif-sur-Yvette, France
* `Elizabeth DuPre`_: Stanford University, Stanford, California, USA
* `Elvis Dohmatob`_: Facebook AI Research (FAIR)
* `Eric Larson`_: Institute for Learning and Brain Sciences, University of Washington, Washington, USA
* `Evan Edmond`_: University of Oxford, Oxford, UK
* `Fabian Pedregosa`_: @google, Geneva, Switzerland
* `Florent Pollet`_: ENS Paris-Saclay, Saclay, France
* `Franz Liem`_
* `François Paugam`_
* `Gael Varoquaux`_: Inria, Saclay, France
* `Gilles de Hollander`_: Vrije Universiteit, Amsterdam, The Netherlands
* `Greg Kiar`_: Child Mind Institute
* `Greydon Gilmore`_: Department of Mathematics, Western University, Toronto, Canada
* `Guillaume Lemaitre`_: Inria, Saclay, France
* `Gustav Magnusson`_: Linköping University, Linköping
* `Hande Gözükan`_: Inria, Saclay, France
* `Hao-Ting Wang`_: Montréal Geriatrics Institute (CRIUGM), Montréal, Canada
* `Himanshu Aggarwal`_: Inria, Saclay, France
* `Ian Abenes`_
* `Idrissa Traore`_: IMT Atlantique, Brest, France
* `Jake Vogel`_: Department of Clinical Sciences, SciLifeLab, Lund University, Lund, Sweden
* `Jan Margeta`_: KardioMe, Nova Dubnica, Slovakia
* `Jaques Grobler`_: Anyline GmbH, Vienna, Austria
* `Jason Gors`_: Insight Data Science, Mountain View, California, USA
* `Jason Kai`_: Child Mind Institute
* `Javier Rasero`_: School of Data Science, University of Virginia, Viginia, USA
* `Jean Kossaifi`_: Imperial College London, London, UK
* `Jean-Rémi King`_: Meta AI, CNRS, Paris
* `Jelle Roelof Dalenberg`_: University Medical Center Groningen, Groningen, The Netherlands
* `Jeremy Lefort-Besnard`_: Inria Rennes, France
* `Jerome Dockes`_: Origami lab, McGill University, Montréal, Canada
* `Jerome-Alexis Chevalier`_: Emerton Data
* `Johannes Wiesner`_: Central Institute of Mental Health, Mannheim, Germany
* `John T. Johnson`_: Neurogram, USA
* `Jon Haitz Legarreta Gorrono`_: Brigham and Women's Hospital, Mass General Brigham/Harvard Medical School, Boston, Massachusetts, USA
* `Jona Sassenhagen`_
* `Jordi Huguet`_: BarcelonaBeta Brain Research Center
* `Joshua Teves`_
* `Julia Huntenburg`_: International Brain Laboratory, Berlin, Germany
* `Julio A Peraza`_: Florida International University, Miami, Florida, USA
* `Kamalakar Reddy Daddy`_
* `Kevin Sitek`_: Northwestern University, Evanston, Ilinois , USA
* `Koen Helwegen`_: Dutch Connectome Lab, VU, Amsterdam, The Netherlands
* `Konrad Wagstyl`_
* `Konstantin Shmelkov`_
* `Kshitij Chawla`_: Duke University Health System, USA
* `Kun CHEN`_: University of Macau, Macau, China
* `Lee Newberg`_: Kitware, Inc., USA
* `Leonard Sasse`_
* `Loic Estève`_
* `Loic Tetrel`_
* `Luz Paz`_
* `Manon Pietrantoni`_
* `Martin Perez-Guevara`_: Criteo, France
* `Martin Wegrzyn`_: Bielefeld University, Bielefeld, Germany
* `Mathias Goncalves`_: Stanford University, Stanford, California, USA
* `Mathieu Dugré`_: Concordia University, Montréal, Canada
* `Matthias Ekman`_: Donders Institute, Nijmegen, The Netherlands
* `Matthieu Joulot`_: Aramis, Paris Brain Institute, Paris, France
* `Maximilian Cosmo Sitter`_
* `Mehdi Rahim`_: Air Liquide, France
* `Mia Zwally`_: DSST, National Institute of Mental Health, USA
* `Micha Burkhardt`_: University of Oldenburg, Germany
* `Michael Eickenberg`_: Flatiron Institute, New-York, New-York, USA
* `Michael Hanke`_: Psychoinformatics, Forschungszentrum Jülich GmbH, Jülich, Germany
* `Michael Notter`_: ams OSRAM, Martigny, Lausanne, Switzerland
* `Michael Waskom`_: Flatiron health, New York, USA
* `Michelle Wang`_: Origami lab, McGill University, Montréal, Canada
* `Mohammad Torabi`_: Origami lab, McGill University, Montréal, Canada
* `Moritz Boos`_
* `Mudassir Chapra`_
* `Myeong Seop Song`_
* `Natasha Clarke`_: @SIMEXP, Montréal, Canada
* `Neelay Shah`_: Max Planck Institute for Intelligent Systems, Germany
* `Nicolas Gensollen`_: Inria, Paris, France
* `Nikhil Krish`_: University of Texas, Austin
* `Oliver Warrington`_: Wellcome Centre for Human Neuroimaging, UCL, London, UK
* `Oscar Esteban`_: Centre Hospitalier Universitaire Vaudoise, Lausanne, Switzerland
* `Patrick Sadil`_: Department of Biostatistics, Johns Hopkins Bloomberg School of Public Health, USA
* `Paul Bogdan`_
* `Paul Reiners`_: Masonic Institute for the Developing Brain, University of Minnesota, USA
* `Paula Sanz-Leon`_: Medical Research Institute, Brisbane, Australia
* `Peer Herholz`_: Origami lab, McGill University, Montréal, Canada
* `Philippe Gervais`_: Zurich, Switzerland
* `Pierre Bellec`_: Psychology Department, University of Montréal, Montréal, Canada
* `Pierre Glaser`_: Gatsby Computational Neuroscience Unit, University College London, London, UK
* `Pierre-Louis Barbarant`_: Inria, Saclay, France
* `Pierre-Olivier Quirion`_: Canadian Center for Computational Genomics / Calcul, Québec, Canada
* `Pradeep Reddy Raamana`_: University of Pittsburgh, Pittsburgh, PA, USA
* `Prakhar Jain`_: RV College of Engineering, Bangalore, India
* `Rahul Brito`_
* `Raphael Meudec`_: Inria, Saclay, France
* `Robert Luke`_: @agencyenterprise, Melbourne, Australia
* `Robert Williamson`_
* `Roberto Guidotti`_: University "G. D'Annunzio" Chieti-Pescara, San Benedetto del Tronto, Italy
* `Rohan Thomas Jepegnanam`_: Cognitive Neuroscience & Clinical Phenomenology Lab, Christian Medical College, Vellore, India
* `Ronald Phlypo`_: Lyon area, France
* `Ryan Hammonds`_: UC San Diego, San Diego, California, USA
* `Rémi Gau`_: Origami lab, McGill University, Montréal, Canada
* `Sachin Patalasingh`_
* `Sage Hahn`_: deephealth
* `Salma Bougacha`_
* `Sam Buck Johnson`_
* `Sami Jawhar`_
* `Simon Steinkamp`_: Danish Research Centre for Magnetic Resonance, Copenhagen University Hospital Amager & Hvidovre, Copenhagen, Denmark.
* `Sin Kim`_: Korea Advanced Institute of Science and Technology: Daejeon, KR
* `Sourav Singh`_
* `Steven Meisler`_: Harvard-MIT Division of Health Sciences and Technology, Cambridge, Massachusetts, USA
* `Suramya Pokharel`_: Tribhuvan University, Kathmandu, Nepal
* `Sylvain Lan`_
* `Sylvain Takerkart`_: CNRS, Institut des Neurosciences de la Timone, Marseille, France
* `Tamer Gezici`_: Bilkent University
* `Tarun Samanta`_: Acharya Prafulla Chandra College
* `Taylor Salo`_: Lifespan Informatics & Neuroimaging Center, University of Pennsylvania, USA
* `Tharun K`_
* `Thiti Premrudeepreechacharn`_
* `Thomas Bazeille`_: Inria, Saclay, France
* `Tom Vanasse`_: Wisconsin Institute for Sleep and Consciousness, USA
* `Vasco Diogo`_
* `Victoria Shevchenko`_: Inria Saclay, Université Paris Cité, France
* `Vincent Michel`_: https://www.logilab.fr/
* `Virgile Fritsch`_: Inria, Saclay, France
* `Yaroslav Halchenko`_: Dartmouth College, PBS, Hanover, New Hampshire, USA
* `Yasmin Mzayek`_: Inria, Saclay, France
* `Yichun Huang`_: Peking University, Beijing, China
* `Zvi Baratz`_: Tel-Aviv University, Israel
* `Óscar Nájera`_: Checkmk

.. OTHER CONTRIBUTION SECTION ENDS HERE

Funding
.......

`Himanshu Aggarwal`_ is paid by `INRIA <https://www.inria.fr/en>`_.

`Rémi Gau`_ is paid by a grant from the
`Chan Zuckerberg Initiative <https://chanzuckerberg.com/eoss/proposals/improving-standard-practice-for-neuroimaging-analyses-with-nilearn/>`_

`Alexandre Abraham`_, `Gael Varoquaux`_, `Kamalakar Reddy Daddy`_, `Loic Estève`_,
`Mehdi Rahim`_, `Philippe Gervais`_ were paid by the
:inria:`NiConnect <parietal/research/spatial_patterns/niconnect/>`.
project, funded by the French `Investissement d'Avenir
<https://www.info.gouv.fr/organisation/secretariat-general-pour-l-investissement-sgpi>`_.

`Kshitij Chawla`_ was paid by `INRIA <https://www.inria.fr/en>`_.

`Yasmin Mzayek`_ and `Nicolas Gensollen`_ were paid by the `Human Brain Project <https://www.humanbrainproject.eu/en/>`_
|HBP logo|.

NiLearn is also supported by `DigiCosme <https://digicosme.cnrs.fr/en/digicosme-paris-saclay-english/>`_
|digicosme logo| and `DataIA <https://www.dataia.eu/en>`_ |dataia_logo|.

.. _citing:

Citing nilearn
--------------

If you want to cite Nilearn, we suggest you do it using our Zenodo DOI:

.. code-block:: bibtex

    @software{Nilearn,
        author = {Nilearn contributors},
        license = {BSD-4-Clause},
        title = {{nilearn}},
        url = {https://github.com/nilearn/nilearn},
        doi = {https://doi.org/10.5281/zenodo.8397156}
    }

Nilearn's Research Resource Identifier (RRID) is:
`RRID:SCR_001362 <https://rrid.site/data/record/nlx_144509-1/SCR_001362/resolver?q=nilearn&l=nilearn&i=rrid:scr_001362>`_

There is no paper published about nilearn.
However, the patterns underlying the package have been described in:
`Machine learning for neuroimaging with scikit-learn <https://doi.org/10.3389/fninf.2014.00014>`_.


Citing scikit-learn
-------------------

A huge amount of work goes into :sklearn:`scikit-learn <>`,
upon which nilearn relies heavily.
Researchers who invest their time in developing and maintaining the package
deserve recognition with citations.
In addition, the :inria:`INRIA MIND Project Team <mind>` needs citations
to the paper in order to justify paying a software engineer on the project.
To guarantee the future of the toolkit, if you use it, please cite it.

See the scikit-learn documentation on
:sklearn:`how to cite <about.html#citing-scikit-learn>`.


.. |digicosme logo| image:: logos/digi-saclay-logo-small.png
    :height: 25
    :alt: DigiComse Logo

.. |dataia_logo| image:: logos/dataia.png
    :height: 25
    :alt: DataIA Logo

.. |HBP logo| image:: logos/hbp-logo.png
    :height: 25
    :alt: HBP Logo
